MRI Apps (`sigpy.mri.app`)
==========================

.. automodule::
   sigpy.mri.app

Regularized MRI Reconstruction
------------------------------
.. autosummary::
   :toctree: generated
   :nosignatures:

   sigpy.mri.app.SenseRecon
   sigpy.mri.app.L1WaveletRecon
   sigpy.mri.app.TotalVariationRecon

Sensitivity Map Estimation
--------------------------
.. autosummary::
   :toctree: generated
   :nosignatures:

   sigpy.mri.app.EspiritCalib
   sigpy.mri.app.JsenseRecon
